==> electron-bootstrap-0.5.3.tgz: package/build-resources/build-frontend.js <==
"use strict";

let systemJSBuilder = new (require("systemjs-builder"))();
systemJSBuilder.config({
    map: {
        "module": "@node/module",
        "console": "@node/console",
        "buffer": "@node/buffer",
        "querystring": "@node/querystring",
        "events": "@node/events",
        "http": "@node/http",
        "cluster": "@node/cluster",
        "zlib": "@node/zlib",
        "os": "@node/os",
        "https": "@node/https",
        "punycode": "@node/punycode",
        "repl": "@node/repl",
        "readline": "@node/readline",
        "vm": "@node/vm",
        "child_process": "@node/child_process",
        "url": "@node/url",
        "dns": "@node/dns",
        "net": "@node/net",
        "dgram": "@node/dgram",
        "fs": "@node/fs",
        "path": "@node/path",
        "string_decoder": "@node/string_decoder",
        "tls": "@node/tls",
        "crypto": "@node/crypto",
        "stream": "@node/stream",
        "util": "@node/util",
        "assert": "@node/assert",
        "tty": "@node/tty",
        "domain": "@node/domain",
        "constants": "@node/constants"
    },
    paths: {
        "app-dev/": "./app-src/frontend/",
        "*": "./node_modules/*"
    },
    transpiler: "plugin-typescript",
    typescriptOptions: {
        "tsconfig": "app-dev/tsconfig.json",
        "typeCheck": "strict"
    },
    packageConfigPaths: [
        "./node_modules/@*/package.json",
        "./node_modules/*/package.json"
    ],
    packages: {
        "app-dev": {
            "main": "app",
            "defaultExtension": "ts",
            "meta": {
                "*.ts": {
                    "loader": "plugin-typescript"
                }
            }
        }
    }
});
systemJSBuilder.buildStatic(
    "./app-src/frontend/app.ts",
    "./app/frontend/app.js",
    {
        minify: true,
        sourceMaps: true
    }
).then(() => {
    console.log("Done!");
});

==> electron-bootstrap-0.5.4.tgz: package/build-resources/build-frontend.js <==
"use strict";

let systemJSBuilder = new (require("systemjs-builder"))();
systemJSBuilder.config({
    map: {
        "module": "@node/module",
        "console": "@node/console",
        "buffer": "@node/buffer",
        "querystring": "@node/querystring",
        "events": "@node/events",
        "http": "@node/http",
        "cluster": "@node/cluster",
        "zlib": "@node/zlib",
        "os": "@node/os",
        "https": "@node/https",
        "punycode": "@node/punycode",
        "repl": "@node/repl",
        "readline": "@node/readline",
        "vm": "@node/vm",
        "child_process": "@node/child_process",
        "url": "@node/url",
        "dns": "@node/dns",
        "net": "@node/net",
        "dgram": "@node/dgram",
        "fs": "@node/fs",
        "path": "@node/path",
        "string_decoder": "@node/string_decoder",
        "tls": "@node/tls",
        "crypto": "@node/crypto",
        "stream": "@node/stream",
        "util": "@node/util",
        "assert": "@node/assert",
        "tty": "@node/tty",
        "domain": "@node/domain",
        "constants": "@node/constants"
    },
    paths: {
        "app-dev/": "./app-src/frontend/",
        "*": "./node_modules/*"
    },
    transpiler: "plugin-typescript",
    typescriptOptions: {
        "tsconfig": "app-dev/tsconfig.json",
        "typeCheck": "strict"
    },
    packageConfigPaths: [
        "./node_modules/@*/*/package.json",
        "./node_modules/*/package.json"
    ],
    packages: {
        "app-dev": {
            "main": "app",
            "defaultExtension": "ts",
            "meta": {
                "*.ts": {
                    "loader": "plugin-typescript"
                }
            }
        }
    }
});
systemJSBuilder.buildStatic(
    "./app-src/frontend/app.ts",
    "./app/frontend/app.js",
    {
        minify: true,
        sourceMaps: true
    }
).then(() => {
    console.log("Done!");
});
